/**
  *  \file client/tiles/planetheader.cc
  *
  *  (c) 2001-2010 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/tiles/planetheader.h"
#include "util/nls.h"
#include "game/planet.h"
#include "cpluslib/format.h"
#include "game/tables.h"
#include "game/config.h"
#include "resmgr/resid.h"

WPlanetScreenHeaderTile::WPlanetScreenHeaderTile(GObjectType& type)
    : WControlScreenHeaderTile(type, bAuto + bAdd + bSend)
{ }

string_t
WPlanetScreenHeaderTile::getTitle()
{
    return getObject()->getName();
}

string_t
WPlanetScreenHeaderTile::getSubtitle()
{
    string_t result;
    if (GPlanet* p = dynamic_cast<GPlanet*>(getObject())) {
        int16 level = p->unit_scores.getScore(planet_score_definitions.lookupScore(ScoreId_ExpLevel));
        const char* fmt = (level >= 0
                           ? _("(Id #%d, %s - %dF, %s)")
                           : _("(Id #%d, %s - %dF)"));
        result = format(fmt,
                        p->getId(),
                        getTemperatureName(p->getTemperature()),
                        p->getTemperature(),
                        getExperienceLevelName(level));
    }
    return result;
}

ResId
WPlanetScreenHeaderTile::getPictureId()
{
    ResId result;
    if (GPlanet* p = dynamic_cast<GPlanet*>(getObject()))
        result = ResId(res::planet, p->getTemperature(), p->getId());
    return result;
}
