/**
  *  \file client/widgets/consoleview.h
  *  \brief Console View
  *
  *  (c) 2001-2010 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_CLIENT_WIDGETS_CONSOLEVIEW_H
#define PCC_V2_CLIENT_WIDGETS_CONSOLEVIEW_H

#include "ui/ui.h"

class Console;

/** Console view. Displays the console output. Uses the widget skin.
    Permits scrolling using external controls. */
class WConsoleView : public UIWidget {
    Console& console;
    SignalConnection conn_console;
    int display_lines;
    int scrollback_lines;
    bool synchronous;

    void onUpdate(const Console& console, int added_lines);
    void limitScrollback();
 public:
    WConsoleView(Console& console, int lines);
    ~WConsoleView();

    void drawContent(GfxCanvas& can);
    void getLayoutInfo(LayoutInfo& info);

    void scrollToEnd();
    void scrollAfterEnd();
    void scrollBack(int lines);

    void setSynchronousMode(bool mode);
};

/** Console view with keyboard handler. Like WConsoleView, displays
    console output, but also accepts keystrokes to scroll it. */
class WConsoleViewWithHandler : public WConsoleView {
 public:
    WConsoleViewWithHandler(Console& console, int lines);
    bool handleEvent(const UIEvent& e, bool second_pass);
};

#endif
