/**
  *  \file client/widgets/dirchoose.h
  *  \brief Game Directory Chooser Widget
  *
  *  (c) 2001-2010 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_CLIENT_WIDGETS_DIRCHOOSE_H
#define PCC_V2_CLIENT_WIDGETS_DIRCHOOSE_H

#include "ui/listbox.h"
#include "io/dirs.h"

/** Directory chooser. */
class WDirectoryChooser : public UIListbox {
 public:
    WDirectoryChooser(int id = 0);
    WDirectoryChooser(Ptr<Directory> dir, bool oneup = false, int id = 0);
    ~WDirectoryChooser();

    void drawPart(GfxCanvas& can, int from, int to);
    void enterCurrent();
    void enterParent();
    void enterDirectory(Ptr<Directory> dir);
    void showDirectory(Ptr<Directory> dir);

    Ptr<Directory> getCurrentDirectory() const;
    Ptr<Directory> getSubdirectory();

    /** Raised when the displayed directory changes. */
    Signal0 sig_dirchange;

 private:
    enum Action {
        aChdir,
        aParent,
        aShowRoots,
        aRescanWithoutGamelist
    };
    enum ScanArg {
        scanGamelist,
        scanNoGamelist,
        scanRoots
    };
    struct Entry {
        Action          a;
        string_t        name;
        Ptr<Directory>  entry;
        Entry(Action a, const string_t& name, Ptr<Directory> entry);
        ~Entry();
    };

    Ptr<Directory> current;
    std::vector<Entry> content;

    void scan(ScanArg arg, Ptr<Directory> dir);
    void scanDirectory(Directory& dir);
    bool readGamelist(Directory& dir);
    static bool isEntryLT(const Entry&, const Entry&);
};

/** Get the directory whose content we are looking at.
    \return directory, or null if we're looking at a virtual directory */
inline Ptr<Directory>
WDirectoryChooser::getCurrentDirectory() const
{
    return current;
}

#endif
