/**
  *  \file client/widgets/funcinfo.cc
  *
  *  (c) 2001-2010 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/widgets/funcinfo.h"
#include "cpluslib/format.h"
#include "util/nls.h"
#include "game/struct.h"
#include "ui/uiglobal.h"
#include "ui/skin.h"
#include "ui/util.h"

WHullFunctionInfo::WHullFunctionInfo()
    : UIWidget()
{ }

WHullFunctionInfo::~WHullFunctionInfo()
{ }

void
WHullFunctionInfo::setFunction(const GHullFunction* hf)
{
    content.clear();
    if (hf != 0) {
        /* Function title */
        const GBasicHullFunction* ptr = GHullFunctionData::instance.getBasicFunctionById(hf->getBasicFunctionId());
        if (ptr)
            content += ptr->getDescription();
        else
            content += format(_("Hull Function #%d"), hf->getBasicFunctionId());
        content += "\n\n";

        /* Availability information */
        string_t tmp = formatPlayerSet(hf->getPlayers());
        if (tmp.size())
            content += format(_("Available to %s\n"), tmp);
        tmp = formatExpLevelSet(hf->getLevels());
        if (tmp.size())
            content += format(_("Available at %s\n"), tmp);

        if (hf->getKind() == GHullFunction::AssignedToRace) {
            if (hf->getPlayers().contains(GPlayerSet::allUpTo(NUM_PLAYERS) - 0))
                content += _("Universal ability\n");
            else
                content += _("Racial ability\n");
        } else if (hf->getKind() == GHullFunction::AssignedToShip) {
            content += _("Assigned to ship\n");
        } else {
            content += _("Assigned to ship class\n");
        }

        content += "\n";

        /* Description */
        if (ptr)
            content += ptr->getExplanation();
    }
    drawWidget();
}

void
WHullFunctionInfo::getLayoutInfo(LayoutInfo& info)
{
    info.min_size = info.pref_size = font_sizes[FONT_NORMAL].scaledBy(30, 10);
    info.flags = li_Flexible;
}

void
WHullFunctionInfo::drawContent(GfxCanvas& can)
{
    GfxContext ctx;
    ctx.useCanvas(can);
    ctx.useColorScheme(getSkin());
    ctx.useFont(*fonts[FONT_NORMAL]);
    ctx.setColor(UIColor::tc_Static);
    drawBackground(ctx, getExtent());
    outTextFormatted(ctx, getExtent().x, getExtent().y, getExtent().w, content);

    can.update(getExtent());
}
